Changelog for Django admin rq
=============================

0.1.4 (2017-03-16)
------------------

- Added Django 1.10 support.


0.1.3 (2016-12-20)
------------------

- The form template learned to output hidden fields without a form-row wrapper.


0.1.2 (2016-12-20)
------------------

- Added form_data block to run template that allows overriding form data.


0.1.1 (2016-04-26)
------------------

- Fixed session key string format error.
- Workflow can start on either form, preview or main views.



0.1.0 (2016-04-20)
------------------

- Initial release.
